/* unattended-file.c generated by valac 0.24.0.112-bbf5, the Vala compiler
 * generated from unattended-file.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <gio/gio.h>
#include <stdlib.h>
#include <string.h>
#include <libvirt-gconfig/libvirt-gconfig.h>
#include <libcommon.h>
#include <gtk/gtk.h>
#include <osinfo/osinfo.h>
#include <gdk-pixbuf/gdk-pixbuf.h>


#define BOXES_TYPE_UNATTENDED_FILE (boxes_unattended_file_get_type ())
#define BOXES_UNATTENDED_FILE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UNATTENDED_FILE, BoxesUnattendedFile))
#define BOXES_IS_UNATTENDED_FILE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UNATTENDED_FILE))
#define BOXES_UNATTENDED_FILE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_UNATTENDED_FILE, BoxesUnattendedFileIface))

typedef struct _BoxesUnattendedFile BoxesUnattendedFile;
typedef struct _BoxesUnattendedFileIface BoxesUnattendedFileIface;

#define BOXES_TYPE_INSTALLER_MEDIA (boxes_installer_media_get_type ())
#define BOXES_INSTALLER_MEDIA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMedia))
#define BOXES_INSTALLER_MEDIA_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMediaClass))
#define BOXES_IS_INSTALLER_MEDIA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_INSTALLER_MEDIA))
#define BOXES_IS_INSTALLER_MEDIA_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_INSTALLER_MEDIA))
#define BOXES_INSTALLER_MEDIA_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMediaClass))

typedef struct _BoxesInstallerMedia BoxesInstallerMedia;
typedef struct _BoxesInstallerMediaClass BoxesInstallerMediaClass;

#define BOXES_TYPE_UNATTENDED_INSTALLER (boxes_unattended_installer_get_type ())
#define BOXES_UNATTENDED_INSTALLER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UNATTENDED_INSTALLER, BoxesUnattendedInstaller))
#define BOXES_UNATTENDED_INSTALLER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_UNATTENDED_INSTALLER, BoxesUnattendedInstallerClass))
#define BOXES_IS_UNATTENDED_INSTALLER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UNATTENDED_INSTALLER))
#define BOXES_IS_UNATTENDED_INSTALLER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_UNATTENDED_INSTALLER))
#define BOXES_UNATTENDED_INSTALLER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_UNATTENDED_INSTALLER, BoxesUnattendedInstallerClass))

typedef struct _BoxesUnattendedInstaller BoxesUnattendedInstaller;
typedef struct _BoxesUnattendedInstallerClass BoxesUnattendedInstallerClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
typedef struct _BoxesInstallerMediaPrivate BoxesInstallerMediaPrivate;

#define BOXES_TYPE_VM_CREATOR (boxes_vm_creator_get_type ())
#define BOXES_VM_CREATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_VM_CREATOR, BoxesVMCreator))
#define BOXES_VM_CREATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_VM_CREATOR, BoxesVMCreatorClass))
#define BOXES_IS_VM_CREATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_VM_CREATOR))
#define BOXES_IS_VM_CREATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_VM_CREATOR))
#define BOXES_VM_CREATOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_VM_CREATOR, BoxesVMCreatorClass))

typedef struct _BoxesVMCreator BoxesVMCreator;
typedef struct _BoxesVMCreatorClass BoxesVMCreatorClass;
typedef struct _BoxesUnattendedInstallerPrivate BoxesUnattendedInstallerPrivate;

#define BOXES_TYPE_UNATTENDED_SETUP_BOX (boxes_unattended_setup_box_get_type ())
#define BOXES_UNATTENDED_SETUP_BOX(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UNATTENDED_SETUP_BOX, BoxesUnattendedSetupBox))
#define BOXES_UNATTENDED_SETUP_BOX_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_UNATTENDED_SETUP_BOX, BoxesUnattendedSetupBoxClass))
#define BOXES_IS_UNATTENDED_SETUP_BOX(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UNATTENDED_SETUP_BOX))
#define BOXES_IS_UNATTENDED_SETUP_BOX_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_UNATTENDED_SETUP_BOX))
#define BOXES_UNATTENDED_SETUP_BOX_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_UNATTENDED_SETUP_BOX, BoxesUnattendedSetupBoxClass))

typedef struct _BoxesUnattendedSetupBox BoxesUnattendedSetupBox;
typedef struct _BoxesUnattendedSetupBoxClass BoxesUnattendedSetupBoxClass;
#define _g_free0(var) (var = (g_free (var), NULL))
typedef struct _BoxesUnattendedFileCopyData BoxesUnattendedFileCopyData;

#define BOXES_TYPE_UNATTENDED_RAW_FILE (boxes_unattended_raw_file_get_type ())
#define BOXES_UNATTENDED_RAW_FILE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UNATTENDED_RAW_FILE, BoxesUnattendedRawFile))
#define BOXES_UNATTENDED_RAW_FILE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_UNATTENDED_RAW_FILE, BoxesUnattendedRawFileClass))
#define BOXES_IS_UNATTENDED_RAW_FILE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UNATTENDED_RAW_FILE))
#define BOXES_IS_UNATTENDED_RAW_FILE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_UNATTENDED_RAW_FILE))
#define BOXES_UNATTENDED_RAW_FILE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_UNATTENDED_RAW_FILE, BoxesUnattendedRawFileClass))

typedef struct _BoxesUnattendedRawFile BoxesUnattendedRawFile;
typedef struct _BoxesUnattendedRawFileClass BoxesUnattendedRawFileClass;
typedef struct _BoxesUnattendedRawFilePrivate BoxesUnattendedRawFilePrivate;
typedef struct _BoxesUnattendedRawFileGetSourceFileData BoxesUnattendedRawFileGetSourceFileData;

#define BOXES_TYPE_UNATTENDED_SCRIPT_FILE (boxes_unattended_script_file_get_type ())
#define BOXES_UNATTENDED_SCRIPT_FILE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UNATTENDED_SCRIPT_FILE, BoxesUnattendedScriptFile))
#define BOXES_UNATTENDED_SCRIPT_FILE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_UNATTENDED_SCRIPT_FILE, BoxesUnattendedScriptFileClass))
#define BOXES_IS_UNATTENDED_SCRIPT_FILE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UNATTENDED_SCRIPT_FILE))
#define BOXES_IS_UNATTENDED_SCRIPT_FILE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_UNATTENDED_SCRIPT_FILE))
#define BOXES_UNATTENDED_SCRIPT_FILE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_UNATTENDED_SCRIPT_FILE, BoxesUnattendedScriptFileClass))

typedef struct _BoxesUnattendedScriptFile BoxesUnattendedScriptFile;
typedef struct _BoxesUnattendedScriptFileClass BoxesUnattendedScriptFileClass;
typedef struct _BoxesUnattendedScriptFilePrivate BoxesUnattendedScriptFilePrivate;
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _BoxesUnattendedScriptFileGetSourceFileData BoxesUnattendedScriptFileGetSourceFileData;

#define BOXES_TYPE_UNATTENDED_AVATAR_FILE (boxes_unattended_avatar_file_get_type ())
#define BOXES_UNATTENDED_AVATAR_FILE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UNATTENDED_AVATAR_FILE, BoxesUnattendedAvatarFile))
#define BOXES_UNATTENDED_AVATAR_FILE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_UNATTENDED_AVATAR_FILE, BoxesUnattendedAvatarFileClass))
#define BOXES_IS_UNATTENDED_AVATAR_FILE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UNATTENDED_AVATAR_FILE))
#define BOXES_IS_UNATTENDED_AVATAR_FILE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_UNATTENDED_AVATAR_FILE))
#define BOXES_UNATTENDED_AVATAR_FILE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_UNATTENDED_AVATAR_FILE, BoxesUnattendedAvatarFileClass))

typedef struct _BoxesUnattendedAvatarFile BoxesUnattendedAvatarFile;
typedef struct _BoxesUnattendedAvatarFileClass BoxesUnattendedAvatarFileClass;
typedef struct _BoxesUnattendedAvatarFilePrivate BoxesUnattendedAvatarFilePrivate;
#define __vala_GdkPixbufFormat_free0(var) ((var == NULL) ? NULL : (var = (_vala_GdkPixbufFormat_free (var), NULL)))
#define _g_list_free0(var) ((var == NULL) ? NULL : (var = (g_list_free (var), NULL)))
#define _g_slist_free0(var) ((var == NULL) ? NULL : (var = (g_slist_free (var), NULL)))
typedef struct _BoxesUnattendedAvatarFileGetSourceFileData BoxesUnattendedAvatarFileGetSourceFileData;

struct _BoxesUnattendedFileIface {
	GTypeInterface parent_iface;
	void (*get_source_file) (BoxesUnattendedFile* self, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	GFile* (*get_source_file_finish) (BoxesUnattendedFile* self, GAsyncResult* _res_, GError** error);
	const gchar* (*get_src_path) (BoxesUnattendedFile* self);
	void (*set_src_path) (BoxesUnattendedFile* self, const gchar* value);
	const gchar* (*get_dest_name) (BoxesUnattendedFile* self);
	void (*set_dest_name) (BoxesUnattendedFile* self, const gchar* value);
	BoxesUnattendedInstaller* (*get_installer) (BoxesUnattendedFile* self);
	void (*set_installer) (BoxesUnattendedFile* self, BoxesUnattendedInstaller* value);
};

struct _BoxesInstallerMedia {
	GObject parent_instance;
	BoxesInstallerMediaPrivate * priv;
	OsinfoOs* os;
	OsinfoResources* resources;
	OsinfoMedia* os_media;
	gchar* label;
	gchar* device_file;
	gchar* mount_point;
	gboolean from_image;
};

struct _BoxesInstallerMediaClass {
	GObjectClass parent_class;
	void (*set_direct_boot_params) (BoxesInstallerMedia* self, GVirConfigDomainOs* os);
	void (*prepare) (BoxesInstallerMedia* self, BoxesActivityProgress* progress, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*prepare_finish) (BoxesInstallerMedia* self, GAsyncResult* _res_);
	void (*prepare_for_installation) (BoxesInstallerMedia* self, const gchar* vm_name, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*prepare_for_installation_finish) (BoxesInstallerMedia* self, GAsyncResult* _res_, GError** error);
	void (*prepare_to_continue_installation) (BoxesInstallerMedia* self, const gchar* vm_name);
	void (*clean_up) (BoxesInstallerMedia* self);
	void (*clean_up_preparation_cache) (BoxesInstallerMedia* self);
	void (*setup_domain_config) (BoxesInstallerMedia* self, GVirConfigDomain* domain);
	void (*setup_post_install_domain_config) (BoxesInstallerMedia* self, GVirConfigDomain* domain);
	void (*populate_setup_box) (BoxesInstallerMedia* self, GtkBox* setup_box);
	GList* (*get_vm_properties) (BoxesInstallerMedia* self);
	BoxesVMCreator* (*get_vm_creator) (BoxesInstallerMedia* self);
	OsinfoDeviceList* (*get_supported_devices) (BoxesInstallerMedia* self);
	guint64 (*get_installed_size) (BoxesInstallerMedia* self);
	gboolean (*get_need_user_input_for_vm_creation) (BoxesInstallerMedia* self);
	gboolean (*get_ready_to_create) (BoxesInstallerMedia* self);
	gboolean (*get_live) (BoxesInstallerMedia* self);
	gchar* (*get_architecture) (BoxesInstallerMedia* self);
};

struct _BoxesUnattendedInstaller {
	BoxesInstallerMedia parent_instance;
	BoxesUnattendedInstallerPrivate * priv;
	BoxesUnattendedSetupBox* setup_box;
	GFile* disk_file;
	GFile* secondary_disk_file;
	GFile* kernel_file;
	GFile* initrd_file;
	OsinfoInstallConfig* config;
	OsinfoInstallScriptList* scripts;
};

struct _BoxesUnattendedInstallerClass {
	BoxesInstallerMediaClass parent_class;
};

struct _BoxesUnattendedFileCopyData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesUnattendedFile* self;
	GCancellable* cancellable;
	GFile* source_file;
	GCancellable* _tmp0_;
	GFile* _tmp1_;
	const gchar* _tmp2_;
	const gchar* _tmp3_;
	BoxesUnattendedInstaller* _tmp4_;
	BoxesUnattendedInstaller* _tmp5_;
	GFile* _tmp6_;
	gchar* _tmp7_;
	gchar* _tmp8_;
	gchar** argv;
	gchar* _tmp9_;
	gchar* _tmp10_;
	gchar* _tmp11_;
	gchar* _tmp12_;
	BoxesUnattendedInstaller* _tmp13_;
	BoxesUnattendedInstaller* _tmp14_;
	GFile* _tmp15_;
	gchar* _tmp16_;
	GFile* _tmp17_;
	gchar* _tmp18_;
	const gchar* _tmp19_;
	const gchar* _tmp20_;
	gchar* _tmp21_;
	gchar** _tmp22_;
	gint argv_length1;
	gint _argv_size_;
	gchar** _tmp23_;
	gint _tmp23__length1;
	GCancellable* _tmp24_;
	const gchar* _tmp25_;
	const gchar* _tmp26_;
	BoxesUnattendedInstaller* _tmp27_;
	BoxesUnattendedInstaller* _tmp28_;
	GFile* _tmp29_;
	gchar* _tmp30_;
	gchar* _tmp31_;
	GError * _inner_error_;
};

struct _BoxesUnattendedRawFile {
	GObject parent_instance;
	BoxesUnattendedRawFilePrivate * priv;
};

struct _BoxesUnattendedRawFileClass {
	GObjectClass parent_class;
};

struct _BoxesUnattendedRawFilePrivate {
	gchar* _dest_name;
	gchar* _src_path;
	BoxesUnattendedInstaller* _installer;
};

struct _BoxesUnattendedRawFileGetSourceFileData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesUnattendedRawFile* self;
	GCancellable* cancellable;
	GFile* result;
	const gchar* _tmp0_;
	const gchar* _tmp1_;
	GFile* _tmp2_;
};

struct _BoxesUnattendedScriptFile {
	GObject parent_instance;
	BoxesUnattendedScriptFilePrivate * priv;
};

struct _BoxesUnattendedScriptFileClass {
	GObjectClass parent_class;
};

struct _BoxesUnattendedScriptFilePrivate {
	gchar* _dest_name;
	gchar* _src_path;
	BoxesUnattendedInstaller* _installer;
	OsinfoInstallScript* _script;
	GFile* unattended_tmp;
};

struct _BoxesUnattendedScriptFileGetSourceFileData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesUnattendedScriptFile* self;
	GCancellable* cancellable;
	GFile* result;
	BoxesUnattendedInstaller* _tmp0_;
	BoxesUnattendedInstaller* _tmp1_;
	OsinfoInstallScript* _tmp2_;
	GFile* output_dir;
	gchar* _tmp3_;
	gchar* _tmp4_;
	GFile* _tmp5_;
	GFile* _tmp6_;
	GFile* _tmp7_;
	OsinfoInstallScript* _tmp8_;
	BoxesUnattendedInstaller* _tmp9_;
	BoxesUnattendedInstaller* _tmp10_;
	OsinfoOs* _tmp11_;
	BoxesUnattendedInstaller* _tmp12_;
	BoxesUnattendedInstaller* _tmp13_;
	OsinfoInstallConfig* _tmp14_;
	GCancellable* _tmp15_;
	GFile* _tmp16_;
	GFile* _tmp17_;
	GFile* _tmp18_;
	GFile* _tmp19_;
	GError * _inner_error_;
};

struct _BoxesUnattendedAvatarFile {
	GObject parent_instance;
	BoxesUnattendedAvatarFilePrivate * priv;
};

struct _BoxesUnattendedAvatarFileClass {
	GObjectClass parent_class;
};

struct _BoxesUnattendedAvatarFilePrivate {
	gchar* _dest_name;
	gchar* _src_path;
	BoxesUnattendedInstaller* _installer;
	GFile* unattended_tmp;
	OsinfoAvatarFormat* avatar_format;
	GdkPixbufFormat* pixbuf_format;
};

struct _BoxesUnattendedAvatarFileGetSourceFileData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesUnattendedAvatarFile* self;
	GCancellable* cancellable;
	GFile* result;
	gchar* destination_path;
	BoxesUnattendedInstaller* _tmp0_;
	BoxesUnattendedInstaller* _tmp1_;
	const gchar* _tmp2_;
	const gchar* _tmp3_;
	gchar* _tmp4_;
	gint _tmp5_;
	OsinfoAvatarFormat* _tmp6_;
	OsinfoAvatarFormat* _tmp7_;
	gint _tmp8_;
	gint _tmp9_;
	gint width;
	gint _tmp10_;
	OsinfoAvatarFormat* _tmp11_;
	OsinfoAvatarFormat* _tmp12_;
	gint _tmp13_;
	gint _tmp14_;
	gint height;
	GdkPixbuf* pixbuf;
	const gchar* _tmp15_;
	const gchar* _tmp16_;
	gint _tmp17_;
	gint _tmp18_;
	GdkPixbuf* _tmp19_;
	gboolean _tmp20_;
	gboolean _tmp21_;
	OsinfoAvatarFormat* _tmp22_;
	OsinfoAvatarFormat* _tmp23_;
	gboolean _tmp24_;
	gboolean _tmp25_;
	GdkPixbuf* _tmp26_;
	gboolean _tmp27_;
	GdkPixbuf* _tmp28_;
	GdkPixbuf* _tmp29_;
	const gchar* _tmp30_;
	GdkPixbuf* _tmp31_;
	const gchar* _tmp32_;
	GdkPixbufFormat* _tmp33_;
	gchar* _tmp34_;
	gchar* _tmp35_;
	const gchar* _tmp36_;
	GError* _error_;
	GError* _tmp37_;
	const gchar* _tmp38_;
	const gchar* _tmp39_;
	GFile* _tmp40_;
	GFile* _tmp41_;
	GFile* _tmp42_;
	GError * _inner_error_;
};


static gpointer boxes_unattended_raw_file_parent_class = NULL;
static BoxesUnattendedFileIface* boxes_unattended_raw_file_boxes_unattended_file_parent_iface = NULL;
static gpointer boxes_unattended_script_file_parent_class = NULL;
static BoxesUnattendedFileIface* boxes_unattended_script_file_boxes_unattended_file_parent_iface = NULL;
static gpointer boxes_unattended_avatar_file_parent_class = NULL;
static BoxesUnattendedFileIface* boxes_unattended_avatar_file_boxes_unattended_file_parent_iface = NULL;

GType boxes_installer_media_get_type (void) G_GNUC_CONST;
GType boxes_unattended_installer_get_type (void) G_GNUC_CONST;
GType boxes_unattended_file_get_type (void) G_GNUC_CONST;
static void boxes_unattended_file_copy_data_free (gpointer _data);
void boxes_unattended_file_copy (BoxesUnattendedFile* self, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_unattended_file_copy_finish (BoxesUnattendedFile* self, GAsyncResult* _res_, GError** error);
static gboolean boxes_unattended_file_copy_co (BoxesUnattendedFileCopyData* _data_);
void boxes_unattended_file_get_source_file (BoxesUnattendedFile* self, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
GFile* boxes_unattended_file_get_source_file_finish (BoxesUnattendedFile* self, GAsyncResult* _res_, GError** error);
static void boxes_unattended_file_copy_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
const gchar* boxes_unattended_file_get_dest_name (BoxesUnattendedFile* self);
BoxesUnattendedInstaller* boxes_unattended_file_get_installer (BoxesUnattendedFile* self);
gpointer boxes_vm_creator_ref (gpointer instance);
void boxes_vm_creator_unref (gpointer instance);
GParamSpec* boxes_param_spec_vm_creator (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void boxes_value_set_vm_creator (GValue* value, gpointer v_object);
void boxes_value_take_vm_creator (GValue* value, gpointer v_object);
gpointer boxes_value_get_vm_creator (const GValue* value);
GType boxes_vm_creator_get_type (void) G_GNUC_CONST;
GType boxes_unattended_setup_box_get_type (void) G_GNUC_CONST;
const gchar* boxes_unattended_file_get_src_path (BoxesUnattendedFile* self);
void boxes_unattended_file_set_src_path (BoxesUnattendedFile* self, const gchar* value);
void boxes_unattended_file_set_dest_name (BoxesUnattendedFile* self, const gchar* value);
void boxes_unattended_file_set_installer (BoxesUnattendedFile* self, BoxesUnattendedInstaller* value);
GType boxes_unattended_raw_file_get_type (void) G_GNUC_CONST;
#define BOXES_UNATTENDED_RAW_FILE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_UNATTENDED_RAW_FILE, BoxesUnattendedRawFilePrivate))
enum  {
	BOXES_UNATTENDED_RAW_FILE_DUMMY_PROPERTY,
	BOXES_UNATTENDED_RAW_FILE_DEST_NAME,
	BOXES_UNATTENDED_RAW_FILE_SRC_PATH,
	BOXES_UNATTENDED_RAW_FILE_INSTALLER
};
BoxesUnattendedRawFile* boxes_unattended_raw_file_new (BoxesUnattendedInstaller* installer, const gchar* src_path, const gchar* dest_name);
BoxesUnattendedRawFile* boxes_unattended_raw_file_construct (GType object_type, BoxesUnattendedInstaller* installer, const gchar* src_path, const gchar* dest_name);
static void boxes_unattended_raw_file_real_get_source_file_data_free (gpointer _data);
static void boxes_unattended_raw_file_real_get_source_file (BoxesUnattendedFile* base, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
static gboolean boxes_unattended_raw_file_real_get_source_file_co (BoxesUnattendedRawFileGetSourceFileData* _data_);
static void boxes_unattended_raw_file_finalize (GObject* obj);
static void _vala_boxes_unattended_raw_file_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_boxes_unattended_raw_file_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
GType boxes_unattended_script_file_get_type (void) G_GNUC_CONST;
#define BOXES_UNATTENDED_SCRIPT_FILE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_UNATTENDED_SCRIPT_FILE, BoxesUnattendedScriptFilePrivate))
enum  {
	BOXES_UNATTENDED_SCRIPT_FILE_DUMMY_PROPERTY,
	BOXES_UNATTENDED_SCRIPT_FILE_DEST_NAME,
	BOXES_UNATTENDED_SCRIPT_FILE_SRC_PATH,
	BOXES_UNATTENDED_SCRIPT_FILE_INSTALLER,
	BOXES_UNATTENDED_SCRIPT_FILE_SCRIPT
};
BoxesUnattendedScriptFile* boxes_unattended_script_file_new (BoxesUnattendedInstaller* installer, OsinfoInstallScript* script, const gchar* dest_name);
BoxesUnattendedScriptFile* boxes_unattended_script_file_construct (GType object_type, BoxesUnattendedInstaller* installer, OsinfoInstallScript* script, const gchar* dest_name);
void boxes_unattended_script_file_set_script (BoxesUnattendedScriptFile* self, OsinfoInstallScript* value);
static void boxes_unattended_script_file_real_get_source_file_data_free (gpointer _data);
static void boxes_unattended_script_file_real_get_source_file (BoxesUnattendedFile* base, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
static gboolean boxes_unattended_script_file_real_get_source_file_co (BoxesUnattendedScriptFileGetSourceFileData* _data_);
void boxes_unattended_installer_configure_install_script (BoxesUnattendedInstaller* self, OsinfoInstallScript* script);
OsinfoInstallScript* boxes_unattended_script_file_get_script (BoxesUnattendedScriptFile* self);
static void boxes_unattended_script_file_get_source_file_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void boxes_unattended_script_file_finalize (GObject* obj);
static void _vala_boxes_unattended_script_file_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_boxes_unattended_script_file_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
GType boxes_unattended_avatar_file_get_type (void) G_GNUC_CONST;
#define BOXES_UNATTENDED_AVATAR_FILE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_UNATTENDED_AVATAR_FILE, BoxesUnattendedAvatarFilePrivate))
enum  {
	BOXES_UNATTENDED_AVATAR_FILE_DUMMY_PROPERTY,
	BOXES_UNATTENDED_AVATAR_FILE_DEST_NAME,
	BOXES_UNATTENDED_AVATAR_FILE_SRC_PATH,
	BOXES_UNATTENDED_AVATAR_FILE_INSTALLER
};
static void _vala_GdkPixbufFormat_free (GdkPixbufFormat* self);
BoxesUnattendedAvatarFile* boxes_unattended_avatar_file_new (BoxesUnattendedInstaller* installer, const gchar* src_path, OsinfoAvatarFormat* avatar_format, GError** error);
BoxesUnattendedAvatarFile* boxes_unattended_avatar_file_construct (GType object_type, BoxesUnattendedInstaller* installer, const gchar* src_path, OsinfoAvatarFormat* avatar_format, GError** error);
static gboolean _vala_string_array_contains (gchar** stack, int stack_length, gchar* needle);
static GdkPixbufFormat* _vala_GdkPixbufFormat_copy (GdkPixbufFormat* self);
const gchar* boxes_unattended_setup_box_get_username (BoxesUnattendedSetupBox* self);
static void boxes_unattended_avatar_file_real_get_source_file_data_free (gpointer _data);
static void boxes_unattended_avatar_file_real_get_source_file (BoxesUnattendedFile* base, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
static gboolean boxes_unattended_avatar_file_real_get_source_file_co (BoxesUnattendedAvatarFileGetSourceFileData* _data_);
gchar* boxes_unattended_installer_get_user_unattended (BoxesUnattendedInstaller* self, const gchar* suffix);
GdkPixbuf* boxes_remove_alpha (GdkPixbuf* pixbuf);
static void boxes_unattended_avatar_file_finalize (GObject* obj);
static void _vala_boxes_unattended_avatar_file_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_boxes_unattended_avatar_file_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
static gint _vala_array_length (gpointer array);


static void boxes_unattended_file_copy_data_free (gpointer _data) {
	BoxesUnattendedFileCopyData* _data_;
	_data_ = _data;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_g_object_unref0 (_data_->cancellable);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_g_object_unref0 (_data_->self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	g_slice_free (BoxesUnattendedFileCopyData, _data_);
#line 481 "unattended-file.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	return self ? g_object_ref (self) : NULL;
#line 488 "unattended-file.c"
}


void boxes_unattended_file_copy (BoxesUnattendedFile* self, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesUnattendedFileCopyData* _data_;
	BoxesUnattendedFile* _tmp0_ = NULL;
	GCancellable* _tmp1_ = NULL;
	GCancellable* _tmp2_ = NULL;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_ = g_slice_new0 (BoxesUnattendedFileCopyData);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_unattended_file_copy);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_unattended_file_copy_data_free);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->self = _tmp0_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_tmp1_ = cancellable;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_g_object_unref0 (_data_->cancellable);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->cancellable = _tmp2_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	boxes_unattended_file_copy_co (_data_);
#line 517 "unattended-file.c"
}


void boxes_unattended_file_copy_finish (BoxesUnattendedFile* self, GAsyncResult* _res_, GError** error) {
	BoxesUnattendedFileCopyData* _data_;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		return;
#line 527 "unattended-file.c"
	}
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 531 "unattended-file.c"
}


static void boxes_unattended_file_copy_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesUnattendedFileCopyData* _data_;
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_ = _user_data_;
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_source_object_ = source_object;
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_res_ = _res_;
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	boxes_unattended_file_copy_co (_data_);
#line 545 "unattended-file.c"
}


static gboolean boxes_unattended_file_copy_co (BoxesUnattendedFileCopyData* _data_) {
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	switch (_data_->_state_) {
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		case 0:
#line 554 "unattended-file.c"
		goto _state_0;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		case 1:
#line 558 "unattended-file.c"
		goto _state_1;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		case 2:
#line 562 "unattended-file.c"
		goto _state_2;
		default:
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		g_assert_not_reached ();
#line 567 "unattended-file.c"
	}
	_state_0:
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp0_ = NULL;
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp0_ = _data_->cancellable;
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_state_ = 1;
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	boxes_unattended_file_get_source_file (_data_->self, _data_->_tmp0_, boxes_unattended_file_copy_ready, _data_);
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	return FALSE;
#line 580 "unattended-file.c"
	_state_1:
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp1_ = NULL;
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp1_ = boxes_unattended_file_get_source_file_finish (_data_->self, _data_->_res_, &_data_->_inner_error_);
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->source_file = _data_->_tmp1_;
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		g_error_free (_data_->_inner_error_);
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		if (_data_->_state_ == 0) {
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 598 "unattended-file.c"
		} else {
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 602 "unattended-file.c"
		}
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		g_object_unref (_data_->_async_result);
#line 12 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		return FALSE;
#line 608 "unattended-file.c"
	}
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp2_ = NULL;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp2_ = boxes_unattended_file_get_dest_name (_data_->self);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp3_ = NULL;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp3_ = _data_->_tmp2_;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp4_ = NULL;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp4_ = boxes_unattended_file_get_installer (_data_->self);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp5_ = NULL;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp5_ = _data_->_tmp4_;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp6_ = NULL;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp6_ = _data_->_tmp5_->disk_file;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp7_ = NULL;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp7_ = g_file_get_path (_data_->_tmp6_);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp8_ = NULL;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp8_ = _data_->_tmp7_;
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	g_debug ("unattended-file.vala:14: Copying unattended file '%s' into disk drive/" \
"image '%s'", _data_->_tmp3_, _data_->_tmp8_);
#line 14 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_g_free0 (_data_->_tmp8_);
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp9_ = NULL;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp9_ = g_strdup ("mcopy");
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp10_ = NULL;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp10_ = g_strdup ("-n");
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp11_ = NULL;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp11_ = g_strdup ("-o");
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp12_ = NULL;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp12_ = g_strdup ("-i");
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp13_ = NULL;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp13_ = boxes_unattended_file_get_installer (_data_->self);
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp14_ = NULL;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp14_ = _data_->_tmp13_;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp15_ = NULL;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp15_ = _data_->_tmp14_->disk_file;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp16_ = NULL;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp16_ = g_file_get_path (_data_->_tmp15_);
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp17_ = NULL;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp17_ = _data_->source_file;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp18_ = NULL;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp18_ = g_file_get_path (_data_->_tmp17_);
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp19_ = NULL;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp19_ = boxes_unattended_file_get_dest_name (_data_->self);
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp20_ = NULL;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp20_ = _data_->_tmp19_;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp21_ = NULL;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp21_ = g_strconcat ("::", _data_->_tmp20_, NULL);
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp22_ = NULL;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp22_ = g_new0 (gchar*, 7 + 1);
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp22_[0] = _data_->_tmp9_;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp22_[1] = _data_->_tmp10_;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp22_[2] = _data_->_tmp11_;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp22_[3] = _data_->_tmp12_;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp22_[4] = _data_->_tmp16_;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp22_[5] = _data_->_tmp18_;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp22_[6] = _data_->_tmp21_;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->argv_length1 = 0;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_argv_size_ = 0;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->argv = _data_->_tmp22_;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->argv_length1 = 7;
#line 16 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_argv_size_ = _data_->argv_length1;
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp23_ = NULL;
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp23__length1 = 0;
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp23_ = _data_->argv;
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp23__length1 = _data_->argv_length1;
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp24_ = NULL;
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp24_ = _data_->cancellable;
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_state_ = 2;
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	boxes_exec (_data_->_tmp23_, _data_->_tmp23__length1, _data_->_tmp24_, boxes_unattended_file_copy_ready, _data_);
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	return FALSE;
#line 740 "unattended-file.c"
	_state_2:
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	boxes_exec_finish (_data_->_res_, NULL, NULL, &_data_->_inner_error_);
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		g_error_free (_data_->_inner_error_);
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		_data_->argv = (_vala_array_free (_data_->argv, _data_->argv_length1, (GDestroyNotify) g_free), NULL);
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		_g_object_unref0 (_data_->source_file);
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		if (_data_->_state_ == 0) {
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 758 "unattended-file.c"
		} else {
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 762 "unattended-file.c"
		}
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		g_object_unref (_data_->_async_result);
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		return FALSE;
#line 768 "unattended-file.c"
	}
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp25_ = NULL;
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp25_ = boxes_unattended_file_get_dest_name (_data_->self);
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp26_ = NULL;
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp26_ = _data_->_tmp25_;
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp27_ = NULL;
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp27_ = boxes_unattended_file_get_installer (_data_->self);
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp28_ = NULL;
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp28_ = _data_->_tmp27_;
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp29_ = NULL;
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp29_ = _data_->_tmp28_->disk_file;
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp30_ = NULL;
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp30_ = g_file_get_path (_data_->_tmp29_);
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp31_ = NULL;
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp31_ = _data_->_tmp30_;
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	g_debug ("unattended-file.vala:20: Copied unattended file '%s' into disk drive/i" \
"mage '%s'", _data_->_tmp26_, _data_->_tmp31_);
#line 20 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_g_free0 (_data_->_tmp31_);
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->argv = (_vala_array_free (_data_->argv, _data_->argv_length1, (GDestroyNotify) g_free), NULL);
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_g_object_unref0 (_data_->source_file);
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	if (_data_->_state_ == 0) {
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 810 "unattended-file.c"
	} else {
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 814 "unattended-file.c"
	}
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	g_object_unref (_data_->_async_result);
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	return FALSE;
#line 820 "unattended-file.c"
}


void boxes_unattended_file_get_source_file (BoxesUnattendedFile* self, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	BOXES_UNATTENDED_FILE_GET_INTERFACE (self)->get_source_file (self, cancellable, _callback_, _user_data_);
#line 827 "unattended-file.c"
}


GFile* boxes_unattended_file_get_source_file_finish (BoxesUnattendedFile* self, GAsyncResult* _res_, GError** error) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	return BOXES_UNATTENDED_FILE_GET_INTERFACE (self)->get_source_file_finish (self, _res_, error);
#line 834 "unattended-file.c"
}


const gchar* boxes_unattended_file_get_src_path (BoxesUnattendedFile* self) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	return BOXES_UNATTENDED_FILE_GET_INTERFACE (self)->get_src_path (self);
#line 843 "unattended-file.c"
}


void boxes_unattended_file_set_src_path (BoxesUnattendedFile* self, const gchar* value) {
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	g_return_if_fail (self != NULL);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	BOXES_UNATTENDED_FILE_GET_INTERFACE (self)->set_src_path (self, value);
#line 852 "unattended-file.c"
}


const gchar* boxes_unattended_file_get_dest_name (BoxesUnattendedFile* self) {
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	return BOXES_UNATTENDED_FILE_GET_INTERFACE (self)->get_dest_name (self);
#line 861 "unattended-file.c"
}


void boxes_unattended_file_set_dest_name (BoxesUnattendedFile* self, const gchar* value) {
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	g_return_if_fail (self != NULL);
#line 7 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	BOXES_UNATTENDED_FILE_GET_INTERFACE (self)->set_dest_name (self, value);
#line 870 "unattended-file.c"
}


BoxesUnattendedInstaller* boxes_unattended_file_get_installer (BoxesUnattendedFile* self) {
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	return BOXES_UNATTENDED_FILE_GET_INTERFACE (self)->get_installer (self);
#line 879 "unattended-file.c"
}


void boxes_unattended_file_set_installer (BoxesUnattendedFile* self, BoxesUnattendedInstaller* value) {
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	g_return_if_fail (self != NULL);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	BOXES_UNATTENDED_FILE_GET_INTERFACE (self)->set_installer (self, value);
#line 888 "unattended-file.c"
}


static void boxes_unattended_file_base_init (BoxesUnattendedFileIface * iface) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	static gboolean initialized = FALSE;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	if (!initialized) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		initialized = TRUE;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		g_object_interface_install_property (iface, g_param_spec_string ("src-path", "src-path", "src-path", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		g_object_interface_install_property (iface, g_param_spec_string ("dest-name", "dest-name", "dest-name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		g_object_interface_install_property (iface, g_param_spec_object ("installer", "installer", "installer", BOXES_TYPE_UNATTENDED_INSTALLER, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 905 "unattended-file.c"
	}
}


GType boxes_unattended_file_get_type (void) {
	static volatile gsize boxes_unattended_file_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_unattended_file_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesUnattendedFileIface), (GBaseInitFunc) boxes_unattended_file_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
		GType boxes_unattended_file_type_id;
		boxes_unattended_file_type_id = g_type_register_static (G_TYPE_INTERFACE, "BoxesUnattendedFile", &g_define_type_info, 0);
		g_type_interface_add_prerequisite (boxes_unattended_file_type_id, G_TYPE_OBJECT);
		g_once_init_leave (&boxes_unattended_file_type_id__volatile, boxes_unattended_file_type_id);
	}
	return boxes_unattended_file_type_id__volatile;
}


BoxesUnattendedRawFile* boxes_unattended_raw_file_construct (GType object_type, BoxesUnattendedInstaller* installer, const gchar* src_path, const gchar* dest_name) {
	BoxesUnattendedRawFile * self = NULL;
	BoxesUnattendedInstaller* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	g_return_val_if_fail (installer != NULL, NULL);
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	g_return_val_if_fail (src_path != NULL, NULL);
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	g_return_val_if_fail (dest_name != NULL, NULL);
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	self = (BoxesUnattendedRawFile*) g_object_new (object_type, NULL);
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_tmp0_ = installer;
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	boxes_unattended_file_set_installer ((BoxesUnattendedFile*) self, _tmp0_);
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_tmp1_ = src_path;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	boxes_unattended_file_set_src_path ((BoxesUnattendedFile*) self, _tmp1_);
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_tmp2_ = dest_name;
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	boxes_unattended_file_set_dest_name ((BoxesUnattendedFile*) self, _tmp2_);
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	return self;
#line 950 "unattended-file.c"
}


BoxesUnattendedRawFile* boxes_unattended_raw_file_new (BoxesUnattendedInstaller* installer, const gchar* src_path, const gchar* dest_name) {
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	return boxes_unattended_raw_file_construct (BOXES_TYPE_UNATTENDED_RAW_FILE, installer, src_path, dest_name);
#line 957 "unattended-file.c"
}


static void boxes_unattended_raw_file_real_get_source_file_data_free (gpointer _data) {
	BoxesUnattendedRawFileGetSourceFileData* _data_;
	_data_ = _data;
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_g_object_unref0 (_data_->cancellable);
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_g_object_unref0 (_data_->result);
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_g_object_unref0 (_data_->self);
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	g_slice_free (BoxesUnattendedRawFileGetSourceFileData, _data_);
#line 972 "unattended-file.c"
}


static void boxes_unattended_raw_file_real_get_source_file (BoxesUnattendedFile* base, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesUnattendedRawFile * self;
	BoxesUnattendedRawFileGetSourceFileData* _data_;
	BoxesUnattendedRawFile* _tmp0_ = NULL;
	GCancellable* _tmp1_ = NULL;
	GCancellable* _tmp2_ = NULL;
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	self = (BoxesUnattendedRawFile*) base;
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_ = g_slice_new0 (BoxesUnattendedRawFileGetSourceFileData);
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_unattended_raw_file_real_get_source_file);
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_unattended_raw_file_real_get_source_file_data_free);
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->self = _tmp0_;
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_tmp1_ = cancellable;
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_g_object_unref0 (_data_->cancellable);
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->cancellable = _tmp2_;
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	boxes_unattended_raw_file_real_get_source_file_co (_data_);
#line 1004 "unattended-file.c"
}


static GFile* boxes_unattended_raw_file_real_get_source_file_finish (BoxesUnattendedFile* base, GAsyncResult* _res_, GError** error) {
	GFile* result;
	BoxesUnattendedRawFileGetSourceFileData* _data_;
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		return NULL;
#line 1015 "unattended-file.c"
	}
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	result = _data_->result;
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->result = NULL;
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	return result;
#line 1025 "unattended-file.c"
}


static gboolean boxes_unattended_raw_file_real_get_source_file_co (BoxesUnattendedRawFileGetSourceFileData* _data_) {
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	switch (_data_->_state_) {
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		case 0:
#line 1034 "unattended-file.c"
		goto _state_0;
		default:
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		g_assert_not_reached ();
#line 1039 "unattended-file.c"
	}
	_state_0:
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp0_ = NULL;
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp0_ = boxes_unattended_file_get_src_path ((BoxesUnattendedFile*) _data_->self);
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp1_ = NULL;
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp1_ = _data_->_tmp0_;
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp2_ = NULL;
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp2_ = g_file_new_for_path (_data_->_tmp1_);
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->result = _data_->_tmp2_;
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	if (_data_->_state_ == 0) {
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1060 "unattended-file.c"
	} else {
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1064 "unattended-file.c"
	}
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	g_object_unref (_data_->_async_result);
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	return FALSE;
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	if (_data_->_state_ == 0) {
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1074 "unattended-file.c"
	} else {
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1078 "unattended-file.c"
	}
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	g_object_unref (_data_->_async_result);
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	return FALSE;
#line 1084 "unattended-file.c"
}


static const gchar* boxes_unattended_raw_file_real_get_dest_name (BoxesUnattendedFile* base) {
	const gchar* result;
	BoxesUnattendedRawFile* self;
	const gchar* _tmp0_ = NULL;
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	self = (BoxesUnattendedRawFile*) base;
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_tmp0_ = self->priv->_dest_name;
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	result = _tmp0_;
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	return result;
#line 1100 "unattended-file.c"
}


static void boxes_unattended_raw_file_real_set_dest_name (BoxesUnattendedFile* base, const gchar* value) {
	BoxesUnattendedRawFile* self;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	self = (BoxesUnattendedRawFile*) base;
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_tmp0_ = value;
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_g_free0 (self->priv->_dest_name);
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	self->priv->_dest_name = _tmp1_;
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	g_object_notify ((GObject *) self, "dest-name");
#line 1120 "unattended-file.c"
}


static const gchar* boxes_unattended_raw_file_real_get_src_path (BoxesUnattendedFile* base) {
	const gchar* result;
	BoxesUnattendedRawFile* self;
	const gchar* _tmp0_ = NULL;
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	self = (BoxesUnattendedRawFile*) base;
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_tmp0_ = self->priv->_src_path;
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	result = _tmp0_;
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	return result;
#line 1136 "unattended-file.c"
}


static void boxes_unattended_raw_file_real_set_src_path (BoxesUnattendedFile* base, const gchar* value) {
	BoxesUnattendedRawFile* self;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	self = (BoxesUnattendedRawFile*) base;
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_tmp0_ = value;
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_g_free0 (self->priv->_src_path);
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	self->priv->_src_path = _tmp1_;
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	g_object_notify ((GObject *) self, "src-path");
#line 1156 "unattended-file.c"
}


static BoxesUnattendedInstaller* boxes_unattended_raw_file_real_get_installer (BoxesUnattendedFile* base) {
	BoxesUnattendedInstaller* result;
	BoxesUnattendedRawFile* self;
	BoxesUnattendedInstaller* _tmp0_ = NULL;
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	self = (BoxesUnattendedRawFile*) base;
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_tmp0_ = self->priv->_installer;
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	result = _tmp0_;
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	return result;
#line 1172 "unattended-file.c"
}


static void boxes_unattended_raw_file_real_set_installer (BoxesUnattendedFile* base, BoxesUnattendedInstaller* value) {
	BoxesUnattendedRawFile* self;
	BoxesUnattendedInstaller* _tmp0_ = NULL;
	BoxesUnattendedInstaller* _tmp1_ = NULL;
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	self = (BoxesUnattendedRawFile*) base;
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_tmp0_ = value;
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_g_object_unref0 (self->priv->_installer);
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	self->priv->_installer = _tmp1_;
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	g_object_notify ((GObject *) self, "installer");
#line 1192 "unattended-file.c"
}


static void boxes_unattended_raw_file_class_init (BoxesUnattendedRawFileClass * klass) {
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	boxes_unattended_raw_file_parent_class = g_type_class_peek_parent (klass);
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	g_type_class_add_private (klass, sizeof (BoxesUnattendedRawFilePrivate));
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_unattended_raw_file_get_property;
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_boxes_unattended_raw_file_set_property;
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_unattended_raw_file_finalize;
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_UNATTENDED_RAW_FILE_DEST_NAME, g_param_spec_string ("dest-name", "dest-name", "dest-name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_UNATTENDED_RAW_FILE_SRC_PATH, g_param_spec_string ("src-path", "src-path", "src-path", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_UNATTENDED_RAW_FILE_INSTALLER, g_param_spec_object ("installer", "installer", "installer", BOXES_TYPE_UNATTENDED_INSTALLER, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 1213 "unattended-file.c"
}


static void boxes_unattended_raw_file_boxes_unattended_file_interface_init (BoxesUnattendedFileIface * iface) {
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	boxes_unattended_raw_file_boxes_unattended_file_parent_iface = g_type_interface_peek_parent (iface);
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	iface->get_source_file = (GFile* (*)(BoxesUnattendedFile*, GCancellable*, GError**)) boxes_unattended_raw_file_real_get_source_file;
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	iface->get_source_file_finish = boxes_unattended_raw_file_real_get_source_file_finish;
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	iface->get_dest_name = boxes_unattended_raw_file_real_get_dest_name;
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	iface->set_dest_name = boxes_unattended_raw_file_real_set_dest_name;
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	iface->get_src_path = boxes_unattended_raw_file_real_get_src_path;
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	iface->set_src_path = boxes_unattended_raw_file_real_set_src_path;
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	iface->get_installer = boxes_unattended_raw_file_real_get_installer;
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	iface->set_installer = boxes_unattended_raw_file_real_set_installer;
#line 1236 "unattended-file.c"
}


static void boxes_unattended_raw_file_instance_init (BoxesUnattendedRawFile * self) {
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	self->priv = BOXES_UNATTENDED_RAW_FILE_GET_PRIVATE (self);
#line 1243 "unattended-file.c"
}


static void boxes_unattended_raw_file_finalize (GObject* obj) {
	BoxesUnattendedRawFile * self;
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_UNATTENDED_RAW_FILE, BoxesUnattendedRawFile);
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_g_free0 (self->priv->_dest_name);
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_g_free0 (self->priv->_src_path);
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_g_object_unref0 (self->priv->_installer);
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	G_OBJECT_CLASS (boxes_unattended_raw_file_parent_class)->finalize (obj);
#line 1259 "unattended-file.c"
}


GType boxes_unattended_raw_file_get_type (void) {
	static volatile gsize boxes_unattended_raw_file_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_unattended_raw_file_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesUnattendedRawFileClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_unattended_raw_file_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesUnattendedRawFile), 0, (GInstanceInitFunc) boxes_unattended_raw_file_instance_init, NULL };
		static const GInterfaceInfo boxes_unattended_file_info = { (GInterfaceInitFunc) boxes_unattended_raw_file_boxes_unattended_file_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType boxes_unattended_raw_file_type_id;
		boxes_unattended_raw_file_type_id = g_type_register_static (G_TYPE_OBJECT, "BoxesUnattendedRawFile", &g_define_type_info, 0);
		g_type_add_interface_static (boxes_unattended_raw_file_type_id, BOXES_TYPE_UNATTENDED_FILE, &boxes_unattended_file_info);
		g_once_init_leave (&boxes_unattended_raw_file_type_id__volatile, boxes_unattended_raw_file_type_id);
	}
	return boxes_unattended_raw_file_type_id__volatile;
}


static void _vala_boxes_unattended_raw_file_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesUnattendedRawFile * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_UNATTENDED_RAW_FILE, BoxesUnattendedRawFile);
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	switch (property_id) {
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		case BOXES_UNATTENDED_RAW_FILE_DEST_NAME:
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		g_value_set_string (value, boxes_unattended_file_get_dest_name ((BoxesUnattendedFile*) self));
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		break;
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		case BOXES_UNATTENDED_RAW_FILE_SRC_PATH:
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		g_value_set_string (value, boxes_unattended_file_get_src_path ((BoxesUnattendedFile*) self));
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		break;
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		case BOXES_UNATTENDED_RAW_FILE_INSTALLER:
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		g_value_set_object (value, boxes_unattended_file_get_installer ((BoxesUnattendedFile*) self));
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		break;
#line 1300 "unattended-file.c"
		default:
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		break;
#line 1306 "unattended-file.c"
	}
}


static void _vala_boxes_unattended_raw_file_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	BoxesUnattendedRawFile * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_UNATTENDED_RAW_FILE, BoxesUnattendedRawFile);
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	switch (property_id) {
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		case BOXES_UNATTENDED_RAW_FILE_DEST_NAME:
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		boxes_unattended_file_set_dest_name ((BoxesUnattendedFile*) self, g_value_get_string (value));
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		break;
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		case BOXES_UNATTENDED_RAW_FILE_SRC_PATH:
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		boxes_unattended_file_set_src_path ((BoxesUnattendedFile*) self, g_value_get_string (value));
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		break;
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		case BOXES_UNATTENDED_RAW_FILE_INSTALLER:
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		boxes_unattended_file_set_installer ((BoxesUnattendedFile*) self, g_value_get_object (value));
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		break;
#line 1334 "unattended-file.c"
		default:
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		break;
#line 1340 "unattended-file.c"
	}
}


BoxesUnattendedScriptFile* boxes_unattended_script_file_construct (GType object_type, BoxesUnattendedInstaller* installer, OsinfoInstallScript* script, const gchar* dest_name) {
	BoxesUnattendedScriptFile * self = NULL;
	BoxesUnattendedInstaller* _tmp0_ = NULL;
	OsinfoInstallScript* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	g_return_val_if_fail (installer != NULL, NULL);
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	g_return_val_if_fail (script != NULL, NULL);
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	g_return_val_if_fail (dest_name != NULL, NULL);
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	self = (BoxesUnattendedScriptFile*) g_object_new (object_type, NULL);
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_tmp0_ = installer;
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	boxes_unattended_file_set_installer ((BoxesUnattendedFile*) self, _tmp0_);
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_tmp1_ = script;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	boxes_unattended_script_file_set_script (self, _tmp1_);
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_tmp2_ = dest_name;
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	boxes_unattended_file_set_dest_name ((BoxesUnattendedFile*) self, _tmp2_);
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	return self;
#line 1372 "unattended-file.c"
}


BoxesUnattendedScriptFile* boxes_unattended_script_file_new (BoxesUnattendedInstaller* installer, OsinfoInstallScript* script, const gchar* dest_name) {
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	return boxes_unattended_script_file_construct (BOXES_TYPE_UNATTENDED_SCRIPT_FILE, installer, script, dest_name);
#line 1379 "unattended-file.c"
}


static void boxes_unattended_script_file_real_get_source_file_data_free (gpointer _data) {
	BoxesUnattendedScriptFileGetSourceFileData* _data_;
	_data_ = _data;
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_g_object_unref0 (_data_->cancellable);
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_g_object_unref0 (_data_->result);
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_g_object_unref0 (_data_->self);
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	g_slice_free (BoxesUnattendedScriptFileGetSourceFileData, _data_);
#line 1394 "unattended-file.c"
}


static void boxes_unattended_script_file_real_get_source_file (BoxesUnattendedFile* base, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesUnattendedScriptFile * self;
	BoxesUnattendedScriptFileGetSourceFileData* _data_;
	BoxesUnattendedScriptFile* _tmp0_ = NULL;
	GCancellable* _tmp1_ = NULL;
	GCancellable* _tmp2_ = NULL;
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	self = (BoxesUnattendedScriptFile*) base;
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_ = g_slice_new0 (BoxesUnattendedScriptFileGetSourceFileData);
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_unattended_script_file_real_get_source_file);
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_unattended_script_file_real_get_source_file_data_free);
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->self = _tmp0_;
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_tmp1_ = cancellable;
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_g_object_unref0 (_data_->cancellable);
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->cancellable = _tmp2_;
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	boxes_unattended_script_file_real_get_source_file_co (_data_);
#line 1426 "unattended-file.c"
}


static GFile* boxes_unattended_script_file_real_get_source_file_finish (BoxesUnattendedFile* base, GAsyncResult* _res_, GError** error) {
	GFile* result;
	BoxesUnattendedScriptFileGetSourceFileData* _data_;
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		return NULL;
#line 1437 "unattended-file.c"
	}
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	result = _data_->result;
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->result = NULL;
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	return result;
#line 1447 "unattended-file.c"
}


static void boxes_unattended_script_file_get_source_file_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesUnattendedScriptFileGetSourceFileData* _data_;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_ = _user_data_;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_source_object_ = source_object;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_res_ = _res_;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	boxes_unattended_script_file_real_get_source_file_co (_data_);
#line 1461 "unattended-file.c"
}


static gboolean boxes_unattended_script_file_real_get_source_file_co (BoxesUnattendedScriptFileGetSourceFileData* _data_) {
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	switch (_data_->_state_) {
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		case 0:
#line 1470 "unattended-file.c"
		goto _state_0;
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		case 1:
#line 1474 "unattended-file.c"
		goto _state_1;
		default:
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		g_assert_not_reached ();
#line 1479 "unattended-file.c"
	}
	_state_0:
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp0_ = NULL;
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp0_ = boxes_unattended_file_get_installer ((BoxesUnattendedFile*) _data_->self);
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp1_ = NULL;
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp1_ = _data_->_tmp0_;
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp2_ = NULL;
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp2_ = _data_->self->priv->_script;
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	boxes_unattended_installer_configure_install_script (_data_->_tmp1_, _data_->_tmp2_);
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp3_ = NULL;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp3_ = boxes_get_user_pkgcache (NULL);
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp4_ = NULL;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp4_ = _data_->_tmp3_;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp5_ = NULL;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp5_ = g_file_new_for_path (_data_->_tmp4_);
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp6_ = NULL;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp6_ = _data_->_tmp5_;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_g_free0 (_data_->_tmp4_);
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->output_dir = _data_->_tmp6_;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp8_ = NULL;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp8_ = _data_->self->priv->_script;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp9_ = NULL;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp9_ = boxes_unattended_file_get_installer ((BoxesUnattendedFile*) _data_->self);
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp10_ = NULL;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp10_ = _data_->_tmp9_;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp11_ = NULL;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp11_ = ((BoxesInstallerMedia*) _data_->_tmp10_)->os;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp12_ = NULL;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp12_ = boxes_unattended_file_get_installer ((BoxesUnattendedFile*) _data_->self);
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp13_ = NULL;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp13_ = _data_->_tmp12_;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp14_ = NULL;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp14_ = _data_->_tmp13_->config;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp15_ = NULL;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp15_ = _data_->cancellable;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_state_ = 1;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	osinfo_install_script_generate_output_async (_data_->_tmp8_, _data_->_tmp11_, _data_->_tmp14_, _data_->output_dir, _data_->_tmp15_, boxes_unattended_script_file_get_source_file_ready, _data_);
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	return FALSE;
#line 1554 "unattended-file.c"
	_state_1:
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp16_ = NULL;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp16_ = osinfo_install_script_generate_output_finish (_data_->_tmp8_, _data_->_res_, &_data_->_inner_error_);
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp7_ = _data_->_tmp16_;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		g_error_free (_data_->_inner_error_);
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		_g_object_unref0 (_data_->output_dir);
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		if (_data_->_state_ == 0) {
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1574 "unattended-file.c"
		} else {
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 1578 "unattended-file.c"
		}
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		g_object_unref (_data_->_async_result);
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		return FALSE;
#line 1584 "unattended-file.c"
	}
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp17_ = NULL;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp17_ = _data_->_tmp7_;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp7_ = NULL;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_g_object_unref0 (_data_->self->priv->unattended_tmp);
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->self->priv->unattended_tmp = _data_->_tmp17_;
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp18_ = NULL;
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp18_ = _data_->self->priv->unattended_tmp;
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp19_ = NULL;
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp19_ = _g_object_ref0 (_data_->_tmp18_);
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->result = _data_->_tmp19_;
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_g_object_unref0 (_data_->_tmp7_);
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_g_object_unref0 (_data_->output_dir);
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	if (_data_->_state_ == 0) {
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1614 "unattended-file.c"
	} else {
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1618 "unattended-file.c"
	}
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	g_object_unref (_data_->_async_result);
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	return FALSE;
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_g_object_unref0 (_data_->_tmp7_);
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_g_object_unref0 (_data_->output_dir);
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	if (_data_->_state_ == 0) {
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1632 "unattended-file.c"
	} else {
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1636 "unattended-file.c"
	}
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	g_object_unref (_data_->_async_result);
#line 69 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	return FALSE;
#line 1642 "unattended-file.c"
}


static const gchar* boxes_unattended_script_file_real_get_dest_name (BoxesUnattendedFile* base) {
	const gchar* result;
	BoxesUnattendedScriptFile* self;
	const gchar* _tmp0_ = NULL;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	self = (BoxesUnattendedScriptFile*) base;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_tmp0_ = self->priv->_dest_name;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	result = _tmp0_;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	return result;
#line 1658 "unattended-file.c"
}


static void boxes_unattended_script_file_real_set_dest_name (BoxesUnattendedFile* base, const gchar* value) {
	BoxesUnattendedScriptFile* self;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	self = (BoxesUnattendedScriptFile*) base;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_tmp0_ = value;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_g_free0 (self->priv->_dest_name);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	self->priv->_dest_name = _tmp1_;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	g_object_notify ((GObject *) self, "dest-name");
#line 1678 "unattended-file.c"
}


static const gchar* boxes_unattended_script_file_real_get_src_path (BoxesUnattendedFile* base) {
	const gchar* result;
	BoxesUnattendedScriptFile* self;
	const gchar* _tmp0_ = NULL;
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	self = (BoxesUnattendedScriptFile*) base;
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_tmp0_ = self->priv->_src_path;
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	result = _tmp0_;
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	return result;
#line 1694 "unattended-file.c"
}


static void boxes_unattended_script_file_real_set_src_path (BoxesUnattendedFile* base, const gchar* value) {
	BoxesUnattendedScriptFile* self;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	self = (BoxesUnattendedScriptFile*) base;
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_tmp0_ = value;
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_g_free0 (self->priv->_src_path);
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	self->priv->_src_path = _tmp1_;
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	g_object_notify ((GObject *) self, "src-path");
#line 1714 "unattended-file.c"
}


static BoxesUnattendedInstaller* boxes_unattended_script_file_real_get_installer (BoxesUnattendedFile* base) {
	BoxesUnattendedInstaller* result;
	BoxesUnattendedScriptFile* self;
	BoxesUnattendedInstaller* _tmp0_ = NULL;
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	self = (BoxesUnattendedScriptFile*) base;
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_tmp0_ = self->priv->_installer;
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	result = _tmp0_;
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	return result;
#line 1730 "unattended-file.c"
}


static void boxes_unattended_script_file_real_set_installer (BoxesUnattendedFile* base, BoxesUnattendedInstaller* value) {
	BoxesUnattendedScriptFile* self;
	BoxesUnattendedInstaller* _tmp0_ = NULL;
	BoxesUnattendedInstaller* _tmp1_ = NULL;
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	self = (BoxesUnattendedScriptFile*) base;
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_tmp0_ = value;
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_g_object_unref0 (self->priv->_installer);
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	self->priv->_installer = _tmp1_;
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	g_object_notify ((GObject *) self, "installer");
#line 1750 "unattended-file.c"
}


OsinfoInstallScript* boxes_unattended_script_file_get_script (BoxesUnattendedScriptFile* self) {
	OsinfoInstallScript* result;
	OsinfoInstallScript* _tmp0_ = NULL;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_tmp0_ = self->priv->_script;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	result = _tmp0_;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	return result;
#line 1765 "unattended-file.c"
}


void boxes_unattended_script_file_set_script (BoxesUnattendedScriptFile* self, OsinfoInstallScript* value) {
	OsinfoInstallScript* _tmp0_ = NULL;
	OsinfoInstallScript* _tmp1_ = NULL;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	g_return_if_fail (self != NULL);
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_tmp0_ = value;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_g_object_unref0 (self->priv->_script);
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	self->priv->_script = _tmp1_;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	g_object_notify ((GObject *) self, "script");
#line 1784 "unattended-file.c"
}


static void boxes_unattended_script_file_class_init (BoxesUnattendedScriptFileClass * klass) {
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	boxes_unattended_script_file_parent_class = g_type_class_peek_parent (klass);
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	g_type_class_add_private (klass, sizeof (BoxesUnattendedScriptFilePrivate));
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_unattended_script_file_get_property;
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_boxes_unattended_script_file_set_property;
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_unattended_script_file_finalize;
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_UNATTENDED_SCRIPT_FILE_DEST_NAME, g_param_spec_string ("dest-name", "dest-name", "dest-name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_UNATTENDED_SCRIPT_FILE_SRC_PATH, g_param_spec_string ("src-path", "src-path", "src-path", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_UNATTENDED_SCRIPT_FILE_INSTALLER, g_param_spec_object ("installer", "installer", "installer", BOXES_TYPE_UNATTENDED_INSTALLER, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_UNATTENDED_SCRIPT_FILE_SCRIPT, g_param_spec_object ("script", "script", "script", osinfo_install_script_get_type (), G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 1807 "unattended-file.c"
}


static void boxes_unattended_script_file_boxes_unattended_file_interface_init (BoxesUnattendedFileIface * iface) {
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	boxes_unattended_script_file_boxes_unattended_file_parent_iface = g_type_interface_peek_parent (iface);
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	iface->get_source_file = (GFile* (*)(BoxesUnattendedFile*, GCancellable*, GError**)) boxes_unattended_script_file_real_get_source_file;
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	iface->get_source_file_finish = boxes_unattended_script_file_real_get_source_file_finish;
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	iface->get_dest_name = boxes_unattended_script_file_real_get_dest_name;
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	iface->set_dest_name = boxes_unattended_script_file_real_set_dest_name;
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	iface->get_src_path = boxes_unattended_script_file_real_get_src_path;
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	iface->set_src_path = boxes_unattended_script_file_real_set_src_path;
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	iface->get_installer = boxes_unattended_script_file_real_get_installer;
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	iface->set_installer = boxes_unattended_script_file_real_set_installer;
#line 1830 "unattended-file.c"
}


static void boxes_unattended_script_file_instance_init (BoxesUnattendedScriptFile * self) {
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	self->priv = BOXES_UNATTENDED_SCRIPT_FILE_GET_PRIVATE (self);
#line 1837 "unattended-file.c"
}


static void boxes_unattended_script_file_finalize (GObject* obj) {
	BoxesUnattendedScriptFile * self;
	GFile* _tmp0_ = NULL;
	GError * _inner_error_ = NULL;
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_UNATTENDED_SCRIPT_FILE, BoxesUnattendedScriptFile);
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_tmp0_ = self->priv->unattended_tmp;
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	if (_tmp0_ == NULL) {
#line 1851 "unattended-file.c"
		goto _return;
	}
	{
		GFile* _tmp1_ = NULL;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		_tmp1_ = self->priv->unattended_tmp;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		boxes_delete_file (_tmp1_, &_inner_error_);
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1862 "unattended-file.c"
			goto __catch79_g_error;
		}
	}
	goto __finally79;
	__catch79_g_error:
	{
		GError* e = NULL;
		GFile* _tmp2_ = NULL;
		gchar* _tmp3_ = NULL;
		gchar* _tmp4_ = NULL;
		GError* _tmp5_ = NULL;
		const gchar* _tmp6_ = NULL;
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		e = _inner_error_;
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		_inner_error_ = NULL;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		_tmp2_ = self->priv->unattended_tmp;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		_tmp3_ = g_file_get_path (_tmp2_);
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		_tmp4_ = _tmp3_;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		_tmp5_ = e;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		_tmp6_ = _tmp5_->message;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		g_warning ("unattended-file.vala:65: Error deleting %s: %s", _tmp4_, _tmp6_);
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		_g_free0 (_tmp4_);
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		_g_error_free0 (e);
#line 1895 "unattended-file.c"
	}
	__finally79:
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		g_clear_error (&_inner_error_);
#line 1904 "unattended-file.c"
	}
	_return:
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_g_free0 (self->priv->_dest_name);
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_g_free0 (self->priv->_src_path);
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_g_object_unref0 (self->priv->_installer);
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_g_object_unref0 (self->priv->_script);
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_g_object_unref0 (self->priv->unattended_tmp);
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	G_OBJECT_CLASS (boxes_unattended_script_file_parent_class)->finalize (obj);
#line 1919 "unattended-file.c"
}


GType boxes_unattended_script_file_get_type (void) {
	static volatile gsize boxes_unattended_script_file_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_unattended_script_file_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesUnattendedScriptFileClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_unattended_script_file_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesUnattendedScriptFile), 0, (GInstanceInitFunc) boxes_unattended_script_file_instance_init, NULL };
		static const GInterfaceInfo boxes_unattended_file_info = { (GInterfaceInitFunc) boxes_unattended_script_file_boxes_unattended_file_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType boxes_unattended_script_file_type_id;
		boxes_unattended_script_file_type_id = g_type_register_static (G_TYPE_OBJECT, "BoxesUnattendedScriptFile", &g_define_type_info, 0);
		g_type_add_interface_static (boxes_unattended_script_file_type_id, BOXES_TYPE_UNATTENDED_FILE, &boxes_unattended_file_info);
		g_once_init_leave (&boxes_unattended_script_file_type_id__volatile, boxes_unattended_script_file_type_id);
	}
	return boxes_unattended_script_file_type_id__volatile;
}


static void _vala_boxes_unattended_script_file_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesUnattendedScriptFile * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_UNATTENDED_SCRIPT_FILE, BoxesUnattendedScriptFile);
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	switch (property_id) {
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		case BOXES_UNATTENDED_SCRIPT_FILE_DEST_NAME:
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		g_value_set_string (value, boxes_unattended_file_get_dest_name ((BoxesUnattendedFile*) self));
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		break;
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		case BOXES_UNATTENDED_SCRIPT_FILE_SRC_PATH:
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		g_value_set_string (value, boxes_unattended_file_get_src_path ((BoxesUnattendedFile*) self));
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		break;
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		case BOXES_UNATTENDED_SCRIPT_FILE_INSTALLER:
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		g_value_set_object (value, boxes_unattended_file_get_installer ((BoxesUnattendedFile*) self));
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		break;
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		case BOXES_UNATTENDED_SCRIPT_FILE_SCRIPT:
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		g_value_set_object (value, boxes_unattended_script_file_get_script (self));
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		break;
#line 1966 "unattended-file.c"
		default:
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		break;
#line 1972 "unattended-file.c"
	}
}


static void _vala_boxes_unattended_script_file_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	BoxesUnattendedScriptFile * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_UNATTENDED_SCRIPT_FILE, BoxesUnattendedScriptFile);
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	switch (property_id) {
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		case BOXES_UNATTENDED_SCRIPT_FILE_DEST_NAME:
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		boxes_unattended_file_set_dest_name ((BoxesUnattendedFile*) self, g_value_get_string (value));
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		break;
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		case BOXES_UNATTENDED_SCRIPT_FILE_SRC_PATH:
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		boxes_unattended_file_set_src_path ((BoxesUnattendedFile*) self, g_value_get_string (value));
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		break;
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		case BOXES_UNATTENDED_SCRIPT_FILE_INSTALLER:
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		boxes_unattended_file_set_installer ((BoxesUnattendedFile*) self, g_value_get_object (value));
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		break;
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		case BOXES_UNATTENDED_SCRIPT_FILE_SCRIPT:
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		boxes_unattended_script_file_set_script (self, g_value_get_object (value));
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		break;
#line 2006 "unattended-file.c"
		default:
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		break;
#line 2012 "unattended-file.c"
	}
}


static void _vala_GdkPixbufFormat_free (GdkPixbufFormat* self) {
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	g_boxed_free (gdk_pixbuf_format_get_type (), self);
#line 2020 "unattended-file.c"
}


static gboolean _vala_string_array_contains (gchar** stack, int stack_length, gchar* needle) {
	int i;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	for (i = 0; i < stack_length; i++) {
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		if (g_strcmp0 (stack[i], needle) == 0) {
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
			return TRUE;
#line 2032 "unattended-file.c"
		}
	}
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	return FALSE;
#line 2037 "unattended-file.c"
}


static GdkPixbufFormat* _vala_GdkPixbufFormat_copy (GdkPixbufFormat* self) {
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	return g_boxed_copy (gdk_pixbuf_format_get_type (), self);
#line 2044 "unattended-file.c"
}


static gpointer __vala_GdkPixbufFormat_copy0 (gpointer self) {
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	return self ? _vala_GdkPixbufFormat_copy (self) : NULL;
#line 2051 "unattended-file.c"
}


BoxesUnattendedAvatarFile* boxes_unattended_avatar_file_construct (GType object_type, BoxesUnattendedInstaller* installer, const gchar* src_path, OsinfoAvatarFormat* avatar_format, GError** error) {
	BoxesUnattendedAvatarFile * self = NULL;
	BoxesUnattendedInstaller* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	OsinfoAvatarFormat* _tmp2_ = NULL;
	OsinfoAvatarFormat* _tmp3_ = NULL;
	GSList* _tmp4_ = NULL;
	GdkPixbufFormat* _tmp24_ = NULL;
	BoxesUnattendedInstaller* _tmp26_ = NULL;
	BoxesUnattendedSetupBox* _tmp27_ = NULL;
	const gchar* _tmp28_ = NULL;
	const gchar* _tmp29_ = NULL;
	gchar* _tmp30_ = NULL;
	gchar* _tmp31_ = NULL;
	GdkPixbufFormat* _tmp32_ = NULL;
	gchar** _tmp33_ = NULL;
	gchar** _tmp34_ = NULL;
	gchar** _tmp35_ = NULL;
	gint _tmp35__length1 = 0;
	const gchar* _tmp36_ = NULL;
	gchar* _tmp37_ = NULL;
	gchar* _tmp38_ = NULL;
	GError * _inner_error_ = NULL;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	g_return_val_if_fail (installer != NULL, NULL);
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	g_return_val_if_fail (src_path != NULL, NULL);
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	self = (BoxesUnattendedAvatarFile*) g_object_new (object_type, NULL);
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_tmp0_ = installer;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	boxes_unattended_file_set_installer ((BoxesUnattendedFile*) self, _tmp0_);
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_tmp1_ = src_path;
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	boxes_unattended_file_set_src_path ((BoxesUnattendedFile*) self, _tmp1_);
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_tmp2_ = avatar_format;
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_g_object_unref0 (self->priv->avatar_format);
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	self->priv->avatar_format = _tmp3_;
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_tmp4_ = gdk_pixbuf_get_formats ();
#line 2102 "unattended-file.c"
	{
		GSList* format_collection = NULL;
		GSList* format_it = NULL;
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		format_collection = _tmp4_;
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		for (format_it = format_collection; format_it != NULL; format_it = format_it->next) {
#line 2110 "unattended-file.c"
			GdkPixbufFormat* format = NULL;
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
			format = (GdkPixbufFormat*) format_it->data;
#line 2114 "unattended-file.c"
			{
				OsinfoAvatarFormat* _tmp5_ = NULL;
				GdkPixbufFormat* _tmp23_ = NULL;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
				_tmp5_ = avatar_format;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
				if (_tmp5_ != NULL) {
#line 2122 "unattended-file.c"
					OsinfoAvatarFormat* _tmp6_ = NULL;
					GList* _tmp7_ = NULL;
					GList* _tmp8_ = NULL;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
					_tmp6_ = avatar_format;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
					_tmp7_ = osinfo_avatar_format_get_mime_types (_tmp6_);
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
					_tmp8_ = _tmp7_;
#line 2132 "unattended-file.c"
					{
						GList* mime_type_collection = NULL;
						GList* mime_type_it = NULL;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
						mime_type_collection = _tmp8_;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
						for (mime_type_it = mime_type_collection; mime_type_it != NULL; mime_type_it = mime_type_it->next) {
#line 2140 "unattended-file.c"
							const gchar* mime_type = NULL;
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
							mime_type = (const gchar*) mime_type_it->data;
#line 2144 "unattended-file.c"
							{
								const gchar* _tmp9_ = NULL;
								GdkPixbufFormat* _tmp10_ = NULL;
								gchar** _tmp11_ = NULL;
								gchar** _tmp12_ = NULL;
								gchar** _tmp13_ = NULL;
								gint _tmp13__length1 = 0;
								gboolean _tmp14_ = FALSE;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
								_tmp9_ = mime_type;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
								_tmp10_ = format;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
								_tmp12_ = _tmp11_ = gdk_pixbuf_format_get_mime_types (_tmp10_);
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
								_tmp13_ = _tmp12_;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
								_tmp13__length1 = _vala_array_length (_tmp11_);
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
								_tmp14_ = _vala_string_array_contains (_tmp13_, _vala_array_length (_tmp11_), _tmp9_);
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
								_tmp13_ = (_vala_array_free (_tmp13_, _tmp13__length1, (GDestroyNotify) g_free), NULL);
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
								if (_tmp14_) {
#line 2169 "unattended-file.c"
									GdkPixbufFormat* _tmp15_ = NULL;
									GdkPixbufFormat* _tmp16_ = NULL;
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
									_tmp15_ = format;
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
									_tmp16_ = __vala_GdkPixbufFormat_copy0 (_tmp15_);
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
									__vala_GdkPixbufFormat_free0 (self->priv->pixbuf_format);
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
									self->priv->pixbuf_format = _tmp16_;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
									break;
#line 2182 "unattended-file.c"
								}
							}
						}
#line 99 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
						_g_list_free0 (mime_type_collection);
#line 2188 "unattended-file.c"
					}
				} else {
					GdkPixbufFormat* _tmp17_ = NULL;
					gchar* _tmp18_ = NULL;
					gchar* _tmp19_ = NULL;
					gboolean _tmp20_ = FALSE;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
					_tmp17_ = format;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
					_tmp18_ = gdk_pixbuf_format_get_name (_tmp17_);
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
					_tmp19_ = _tmp18_;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
					_tmp20_ = g_strcmp0 (_tmp19_, "png") == 0;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
					_g_free0 (_tmp19_);
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
					if (_tmp20_) {
#line 2207 "unattended-file.c"
						GdkPixbufFormat* _tmp21_ = NULL;
						GdkPixbufFormat* _tmp22_ = NULL;
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
						_tmp21_ = format;
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
						_tmp22_ = __vala_GdkPixbufFormat_copy0 (_tmp21_);
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
						__vala_GdkPixbufFormat_free0 (self->priv->pixbuf_format);
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
						self->priv->pixbuf_format = _tmp22_;
#line 2218 "unattended-file.c"
					}
				}
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
				_tmp23_ = self->priv->pixbuf_format;
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
				if (_tmp23_ != NULL) {
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
					break;
#line 2227 "unattended-file.c"
				}
			}
		}
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		_g_slist_free0 (format_collection);
#line 2233 "unattended-file.c"
	}
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_tmp24_ = self->priv->pixbuf_format;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	if (_tmp24_ == NULL) {
#line 2239 "unattended-file.c"
		GError* _tmp25_ = NULL;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		_tmp25_ = g_error_new_literal (BOXES_ERROR, BOXES_ERROR_INVALID, "Failed to find suitable format to save user avatar file in.");
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		_inner_error_ = _tmp25_;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		if (_inner_error_->domain == BOXES_ERROR) {
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
			g_propagate_error (error, _inner_error_);
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
			_g_object_unref0 (self);
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
			return NULL;
#line 2253 "unattended-file.c"
		} else {
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
			g_clear_error (&_inner_error_);
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
			return NULL;
#line 2261 "unattended-file.c"
		}
	}
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_tmp26_ = installer;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_tmp27_ = _tmp26_->setup_box;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_tmp28_ = boxes_unattended_setup_box_get_username (_tmp27_);
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_tmp29_ = _tmp28_;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_tmp30_ = g_strconcat (_tmp29_, ".", NULL);
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_tmp31_ = _tmp30_;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_tmp32_ = self->priv->pixbuf_format;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_tmp34_ = _tmp33_ = gdk_pixbuf_format_get_extensions (_tmp32_);
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_tmp35_ = _tmp34_;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_tmp35__length1 = _vala_array_length (_tmp33_);
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_tmp36_ = _tmp35_[0];
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_tmp37_ = g_strconcat (_tmp31_, _tmp36_, NULL);
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_tmp38_ = _tmp37_;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	boxes_unattended_file_set_dest_name ((BoxesUnattendedFile*) self, _tmp38_);
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_g_free0 (_tmp38_);
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_tmp35_ = (_vala_array_free (_tmp35_, _tmp35__length1, (GDestroyNotify) g_free), NULL);
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_g_free0 (_tmp31_);
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	return self;
#line 2300 "unattended-file.c"
}


BoxesUnattendedAvatarFile* boxes_unattended_avatar_file_new (BoxesUnattendedInstaller* installer, const gchar* src_path, OsinfoAvatarFormat* avatar_format, GError** error) {
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	return boxes_unattended_avatar_file_construct (BOXES_TYPE_UNATTENDED_AVATAR_FILE, installer, src_path, avatar_format, error);
#line 2307 "unattended-file.c"
}


static void boxes_unattended_avatar_file_real_get_source_file_data_free (gpointer _data) {
	BoxesUnattendedAvatarFileGetSourceFileData* _data_;
	_data_ = _data;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_g_object_unref0 (_data_->cancellable);
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_g_object_unref0 (_data_->result);
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_g_object_unref0 (_data_->self);
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	g_slice_free (BoxesUnattendedAvatarFileGetSourceFileData, _data_);
#line 2322 "unattended-file.c"
}


static void boxes_unattended_avatar_file_real_get_source_file (BoxesUnattendedFile* base, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesUnattendedAvatarFile * self;
	BoxesUnattendedAvatarFileGetSourceFileData* _data_;
	BoxesUnattendedAvatarFile* _tmp0_ = NULL;
	GCancellable* _tmp1_ = NULL;
	GCancellable* _tmp2_ = NULL;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	self = (BoxesUnattendedAvatarFile*) base;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_ = g_slice_new0 (BoxesUnattendedAvatarFileGetSourceFileData);
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_unattended_avatar_file_real_get_source_file);
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_unattended_avatar_file_real_get_source_file_data_free);
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->self = _tmp0_;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_tmp1_ = cancellable;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_g_object_unref0 (_data_->cancellable);
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->cancellable = _tmp2_;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	boxes_unattended_avatar_file_real_get_source_file_co (_data_);
#line 2354 "unattended-file.c"
}


static GFile* boxes_unattended_avatar_file_real_get_source_file_finish (BoxesUnattendedFile* base, GAsyncResult* _res_, GError** error) {
	GFile* result;
	BoxesUnattendedAvatarFileGetSourceFileData* _data_;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		return NULL;
#line 2365 "unattended-file.c"
	}
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	result = _data_->result;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->result = NULL;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	return result;
#line 2375 "unattended-file.c"
}


static gboolean boxes_unattended_avatar_file_real_get_source_file_co (BoxesUnattendedAvatarFileGetSourceFileData* _data_) {
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	switch (_data_->_state_) {
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		case 0:
#line 2384 "unattended-file.c"
		goto _state_0;
		default:
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		g_assert_not_reached ();
#line 2389 "unattended-file.c"
	}
	_state_0:
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp0_ = NULL;
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp0_ = boxes_unattended_file_get_installer ((BoxesUnattendedFile*) _data_->self);
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp1_ = NULL;
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp1_ = _data_->_tmp0_;
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp2_ = NULL;
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp2_ = boxes_unattended_file_get_dest_name ((BoxesUnattendedFile*) _data_->self);
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp3_ = NULL;
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp3_ = _data_->_tmp2_;
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp4_ = NULL;
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp4_ = boxes_unattended_installer_get_user_unattended (_data_->_tmp1_, _data_->_tmp3_);
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->destination_path = _data_->_tmp4_;
#line 2414 "unattended-file.c"
	{
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		_data_->_tmp6_ = NULL;
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		_data_->_tmp6_ = _data_->self->priv->avatar_format;
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		if (_data_->_tmp6_ != NULL) {
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
			_data_->_tmp7_ = NULL;
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
			_data_->_tmp7_ = _data_->self->priv->avatar_format;
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
			_data_->_tmp8_ = 0;
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
			_data_->_tmp8_ = osinfo_avatar_format_get_width (_data_->_tmp7_);
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
			_data_->_tmp9_ = 0;
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
			_data_->_tmp9_ = _data_->_tmp8_;
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
			_data_->_tmp5_ = _data_->_tmp9_;
#line 2436 "unattended-file.c"
		} else {
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
			_data_->_tmp5_ = -1;
#line 2440 "unattended-file.c"
		}
#line 134 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		_data_->width = _data_->_tmp5_;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		_data_->_tmp11_ = NULL;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		_data_->_tmp11_ = _data_->self->priv->avatar_format;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		if (_data_->_tmp11_ != NULL) {
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
			_data_->_tmp12_ = NULL;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
			_data_->_tmp12_ = _data_->self->priv->avatar_format;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
			_data_->_tmp13_ = 0;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
			_data_->_tmp13_ = osinfo_avatar_format_get_height (_data_->_tmp12_);
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
			_data_->_tmp14_ = 0;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
			_data_->_tmp14_ = _data_->_tmp13_;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
			_data_->_tmp10_ = _data_->_tmp14_;
#line 2464 "unattended-file.c"
		} else {
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
			_data_->_tmp10_ = -1;
#line 2468 "unattended-file.c"
		}
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		_data_->height = _data_->_tmp10_;
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		_data_->_tmp15_ = NULL;
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		_data_->_tmp15_ = boxes_unattended_file_get_src_path ((BoxesUnattendedFile*) _data_->self);
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		_data_->_tmp16_ = NULL;
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		_data_->_tmp16_ = _data_->_tmp15_;
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		_data_->_tmp17_ = 0;
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		_data_->_tmp17_ = _data_->width;
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		_data_->_tmp18_ = 0;
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		_data_->_tmp18_ = _data_->height;
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		_data_->_tmp19_ = NULL;
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		_data_->_tmp19_ = gdk_pixbuf_new_from_file_at_scale (_data_->_tmp16_, _data_->_tmp17_, _data_->_tmp18_, TRUE, &_data_->_inner_error_);
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		_data_->pixbuf = _data_->_tmp19_;
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 2496 "unattended-file.c"
			goto __catch81_g_error;
		}
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		_data_->_tmp22_ = NULL;
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		_data_->_tmp22_ = _data_->self->priv->avatar_format;
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		if (_data_->_tmp22_ != NULL) {
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
			_data_->_tmp23_ = NULL;
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
			_data_->_tmp23_ = _data_->self->priv->avatar_format;
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
			_data_->_tmp24_ = FALSE;
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
			_data_->_tmp24_ = osinfo_avatar_format_get_alpha (_data_->_tmp23_);
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
			_data_->_tmp25_ = FALSE;
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
			_data_->_tmp25_ = _data_->_tmp24_;
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
			_data_->_tmp21_ = !_data_->_tmp25_;
#line 2519 "unattended-file.c"
		} else {
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
			_data_->_tmp21_ = FALSE;
#line 2523 "unattended-file.c"
		}
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		if (_data_->_tmp21_) {
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
			_data_->_tmp26_ = NULL;
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
			_data_->_tmp26_ = _data_->pixbuf;
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
			_data_->_tmp27_ = FALSE;
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
			_data_->_tmp27_ = gdk_pixbuf_get_has_alpha (_data_->_tmp26_);
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
			_data_->_tmp20_ = _data_->_tmp27_;
#line 2537 "unattended-file.c"
		} else {
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
			_data_->_tmp20_ = FALSE;
#line 2541 "unattended-file.c"
		}
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		if (_data_->_tmp20_) {
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
			_data_->_tmp28_ = NULL;
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
			_data_->_tmp28_ = _data_->pixbuf;
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
			_data_->_tmp29_ = NULL;
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
			_data_->_tmp29_ = boxes_remove_alpha (_data_->_tmp28_);
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
			_g_object_unref0 (_data_->pixbuf);
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
			_data_->pixbuf = _data_->_tmp29_;
#line 2557 "unattended-file.c"
		}
#line 141 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		_data_->_tmp30_ = NULL;
#line 141 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		_data_->_tmp30_ = _data_->destination_path;
#line 141 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		g_debug ("unattended-file.vala:141: Saving user avatar file at '%s'..", _data_->_tmp30_);
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		_data_->_tmp31_ = NULL;
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		_data_->_tmp31_ = _data_->pixbuf;
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		_data_->_tmp32_ = NULL;
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		_data_->_tmp32_ = _data_->destination_path;
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		_data_->_tmp33_ = NULL;
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		_data_->_tmp33_ = _data_->self->priv->pixbuf_format;
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		_data_->_tmp34_ = NULL;
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		_data_->_tmp34_ = gdk_pixbuf_format_get_name (_data_->_tmp33_);
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		_data_->_tmp35_ = NULL;
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		_data_->_tmp35_ = _data_->_tmp34_;
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		gdk_pixbuf_save (_data_->_tmp31_, _data_->_tmp32_, _data_->_tmp35_, &_data_->_inner_error_, NULL);
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		_g_free0 (_data_->_tmp35_);
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 142 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
			_g_object_unref0 (_data_->pixbuf);
#line 2593 "unattended-file.c"
			goto __catch81_g_error;
		}
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		_data_->_tmp36_ = NULL;
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		_data_->_tmp36_ = _data_->destination_path;
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		g_debug ("unattended-file.vala:143: Saved user avatar file at '%s'.", _data_->_tmp36_);
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		_g_object_unref0 (_data_->pixbuf);
#line 2604 "unattended-file.c"
	}
	goto __finally81;
	__catch81_g_error:
	{
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		_data_->_error_ = _data_->_inner_error_;
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		_data_->_inner_error_ = NULL;
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		_data_->_tmp37_ = NULL;
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		_data_->_tmp37_ = _data_->_error_;
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		_data_->_tmp38_ = NULL;
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		_data_->_tmp38_ = _data_->_tmp37_->message;
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		g_warning ("unattended-file.vala:145: Failed to save user avatar: %s.", _data_->_tmp38_);
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		_g_error_free0 (_data_->_error_);
#line 2625 "unattended-file.c"
	}
	__finally81:
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		g_error_free (_data_->_inner_error_);
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		_g_free0 (_data_->destination_path);
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		if (_data_->_state_ == 0) {
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2640 "unattended-file.c"
		} else {
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 2644 "unattended-file.c"
		}
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		g_object_unref (_data_->_async_result);
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		return FALSE;
#line 2650 "unattended-file.c"
	}
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp39_ = NULL;
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp39_ = _data_->destination_path;
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp40_ = NULL;
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp40_ = g_file_new_for_path (_data_->_tmp39_);
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_g_object_unref0 (_data_->self->priv->unattended_tmp);
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->self->priv->unattended_tmp = _data_->_tmp40_;
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp41_ = NULL;
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp41_ = _data_->self->priv->unattended_tmp;
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp42_ = NULL;
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->_tmp42_ = _g_object_ref0 (_data_->_tmp41_);
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_data_->result = _data_->_tmp42_;
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_g_free0 (_data_->destination_path);
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	if (_data_->_state_ == 0) {
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2680 "unattended-file.c"
	} else {
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 2684 "unattended-file.c"
	}
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	g_object_unref (_data_->_async_result);
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	return FALSE;
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_g_free0 (_data_->destination_path);
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	if (_data_->_state_ == 0) {
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2696 "unattended-file.c"
	} else {
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 2700 "unattended-file.c"
	}
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	g_object_unref (_data_->_async_result);
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	return FALSE;
#line 2706 "unattended-file.c"
}


static const gchar* boxes_unattended_avatar_file_real_get_dest_name (BoxesUnattendedFile* base) {
	const gchar* result;
	BoxesUnattendedAvatarFile* self;
	const gchar* _tmp0_ = NULL;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	self = (BoxesUnattendedAvatarFile*) base;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_tmp0_ = self->priv->_dest_name;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	result = _tmp0_;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	return result;
#line 2722 "unattended-file.c"
}


static void boxes_unattended_avatar_file_real_set_dest_name (BoxesUnattendedFile* base, const gchar* value) {
	BoxesUnattendedAvatarFile* self;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	self = (BoxesUnattendedAvatarFile*) base;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_tmp0_ = value;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_g_free0 (self->priv->_dest_name);
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	self->priv->_dest_name = _tmp1_;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	g_object_notify ((GObject *) self, "dest-name");
#line 2742 "unattended-file.c"
}


static const gchar* boxes_unattended_avatar_file_real_get_src_path (BoxesUnattendedFile* base) {
	const gchar* result;
	BoxesUnattendedAvatarFile* self;
	const gchar* _tmp0_ = NULL;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	self = (BoxesUnattendedAvatarFile*) base;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_tmp0_ = self->priv->_src_path;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	result = _tmp0_;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	return result;
#line 2758 "unattended-file.c"
}


static void boxes_unattended_avatar_file_real_set_src_path (BoxesUnattendedFile* base, const gchar* value) {
	BoxesUnattendedAvatarFile* self;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	self = (BoxesUnattendedAvatarFile*) base;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_tmp0_ = value;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_g_free0 (self->priv->_src_path);
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	self->priv->_src_path = _tmp1_;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	g_object_notify ((GObject *) self, "src-path");
#line 2778 "unattended-file.c"
}


static BoxesUnattendedInstaller* boxes_unattended_avatar_file_real_get_installer (BoxesUnattendedFile* base) {
	BoxesUnattendedInstaller* result;
	BoxesUnattendedAvatarFile* self;
	BoxesUnattendedInstaller* _tmp0_ = NULL;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	self = (BoxesUnattendedAvatarFile*) base;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_tmp0_ = self->priv->_installer;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	result = _tmp0_;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	return result;
#line 2794 "unattended-file.c"
}


static void boxes_unattended_avatar_file_real_set_installer (BoxesUnattendedFile* base, BoxesUnattendedInstaller* value) {
	BoxesUnattendedAvatarFile* self;
	BoxesUnattendedInstaller* _tmp0_ = NULL;
	BoxesUnattendedInstaller* _tmp1_ = NULL;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	self = (BoxesUnattendedAvatarFile*) base;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_tmp0_ = value;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_g_object_unref0 (self->priv->_installer);
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	self->priv->_installer = _tmp1_;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	g_object_notify ((GObject *) self, "installer");
#line 2814 "unattended-file.c"
}


static void boxes_unattended_avatar_file_class_init (BoxesUnattendedAvatarFileClass * klass) {
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	boxes_unattended_avatar_file_parent_class = g_type_class_peek_parent (klass);
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	g_type_class_add_private (klass, sizeof (BoxesUnattendedAvatarFilePrivate));
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_unattended_avatar_file_get_property;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_boxes_unattended_avatar_file_set_property;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_unattended_avatar_file_finalize;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_UNATTENDED_AVATAR_FILE_DEST_NAME, g_param_spec_string ("dest-name", "dest-name", "dest-name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_UNATTENDED_AVATAR_FILE_SRC_PATH, g_param_spec_string ("src-path", "src-path", "src-path", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_UNATTENDED_AVATAR_FILE_INSTALLER, g_param_spec_object ("installer", "installer", "installer", BOXES_TYPE_UNATTENDED_INSTALLER, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 2835 "unattended-file.c"
}


static void boxes_unattended_avatar_file_boxes_unattended_file_interface_init (BoxesUnattendedFileIface * iface) {
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	boxes_unattended_avatar_file_boxes_unattended_file_parent_iface = g_type_interface_peek_parent (iface);
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	iface->get_source_file = (GFile* (*)(BoxesUnattendedFile*, GCancellable*, GError**)) boxes_unattended_avatar_file_real_get_source_file;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	iface->get_source_file_finish = boxes_unattended_avatar_file_real_get_source_file_finish;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	iface->get_dest_name = boxes_unattended_avatar_file_real_get_dest_name;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	iface->set_dest_name = boxes_unattended_avatar_file_real_set_dest_name;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	iface->get_src_path = boxes_unattended_avatar_file_real_get_src_path;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	iface->set_src_path = boxes_unattended_avatar_file_real_set_src_path;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	iface->get_installer = boxes_unattended_avatar_file_real_get_installer;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	iface->set_installer = boxes_unattended_avatar_file_real_set_installer;
#line 2858 "unattended-file.c"
}


static void boxes_unattended_avatar_file_instance_init (BoxesUnattendedAvatarFile * self) {
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	self->priv = BOXES_UNATTENDED_AVATAR_FILE_GET_PRIVATE (self);
#line 2865 "unattended-file.c"
}


static void boxes_unattended_avatar_file_finalize (GObject* obj) {
	BoxesUnattendedAvatarFile * self;
	GFile* _tmp0_ = NULL;
	GError * _inner_error_ = NULL;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_UNATTENDED_AVATAR_FILE, BoxesUnattendedAvatarFile);
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_tmp0_ = self->priv->unattended_tmp;
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	if (_tmp0_ == NULL) {
#line 2879 "unattended-file.c"
		goto _return;
	}
	{
		GFile* _tmp1_ = NULL;
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		_tmp1_ = self->priv->unattended_tmp;
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		boxes_delete_file (_tmp1_, &_inner_error_);
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2890 "unattended-file.c"
			goto __catch80_g_error;
		}
	}
	goto __finally80;
	__catch80_g_error:
	{
		GError* e = NULL;
		GFile* _tmp2_ = NULL;
		gchar* _tmp3_ = NULL;
		gchar* _tmp4_ = NULL;
		GError* _tmp5_ = NULL;
		const gchar* _tmp6_ = NULL;
#line 123 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		e = _inner_error_;
#line 123 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		_inner_error_ = NULL;
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		_tmp2_ = self->priv->unattended_tmp;
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		_tmp3_ = g_file_get_path (_tmp2_);
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		_tmp4_ = _tmp3_;
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		_tmp5_ = e;
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		_tmp6_ = _tmp5_->message;
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		g_warning ("unattended-file.vala:126: Error deleting %s: %s", _tmp4_, _tmp6_);
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		_g_free0 (_tmp4_);
#line 123 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		_g_error_free0 (e);
#line 2923 "unattended-file.c"
	}
	__finally80:
#line 123 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 123 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 123 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		g_clear_error (&_inner_error_);
#line 2932 "unattended-file.c"
	}
	_return:
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_g_free0 (self->priv->_dest_name);
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_g_free0 (self->priv->_src_path);
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_g_object_unref0 (self->priv->_installer);
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_g_object_unref0 (self->priv->unattended_tmp);
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	_g_object_unref0 (self->priv->avatar_format);
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	__vala_GdkPixbufFormat_free0 (self->priv->pixbuf_format);
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	G_OBJECT_CLASS (boxes_unattended_avatar_file_parent_class)->finalize (obj);
#line 2949 "unattended-file.c"
}


GType boxes_unattended_avatar_file_get_type (void) {
	static volatile gsize boxes_unattended_avatar_file_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_unattended_avatar_file_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesUnattendedAvatarFileClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_unattended_avatar_file_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesUnattendedAvatarFile), 0, (GInstanceInitFunc) boxes_unattended_avatar_file_instance_init, NULL };
		static const GInterfaceInfo boxes_unattended_file_info = { (GInterfaceInitFunc) boxes_unattended_avatar_file_boxes_unattended_file_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType boxes_unattended_avatar_file_type_id;
		boxes_unattended_avatar_file_type_id = g_type_register_static (G_TYPE_OBJECT, "BoxesUnattendedAvatarFile", &g_define_type_info, 0);
		g_type_add_interface_static (boxes_unattended_avatar_file_type_id, BOXES_TYPE_UNATTENDED_FILE, &boxes_unattended_file_info);
		g_once_init_leave (&boxes_unattended_avatar_file_type_id__volatile, boxes_unattended_avatar_file_type_id);
	}
	return boxes_unattended_avatar_file_type_id__volatile;
}


static void _vala_boxes_unattended_avatar_file_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesUnattendedAvatarFile * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_UNATTENDED_AVATAR_FILE, BoxesUnattendedAvatarFile);
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	switch (property_id) {
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		case BOXES_UNATTENDED_AVATAR_FILE_DEST_NAME:
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		g_value_set_string (value, boxes_unattended_file_get_dest_name ((BoxesUnattendedFile*) self));
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		break;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		case BOXES_UNATTENDED_AVATAR_FILE_SRC_PATH:
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		g_value_set_string (value, boxes_unattended_file_get_src_path ((BoxesUnattendedFile*) self));
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		break;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		case BOXES_UNATTENDED_AVATAR_FILE_INSTALLER:
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		g_value_set_object (value, boxes_unattended_file_get_installer ((BoxesUnattendedFile*) self));
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		break;
#line 2990 "unattended-file.c"
		default:
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		break;
#line 2996 "unattended-file.c"
	}
}


static void _vala_boxes_unattended_avatar_file_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	BoxesUnattendedAvatarFile * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_UNATTENDED_AVATAR_FILE, BoxesUnattendedAvatarFile);
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
	switch (property_id) {
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		case BOXES_UNATTENDED_AVATAR_FILE_DEST_NAME:
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		boxes_unattended_file_set_dest_name ((BoxesUnattendedFile*) self, g_value_get_string (value));
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		break;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		case BOXES_UNATTENDED_AVATAR_FILE_SRC_PATH:
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		boxes_unattended_file_set_src_path ((BoxesUnattendedFile*) self, g_value_get_string (value));
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		break;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		case BOXES_UNATTENDED_AVATAR_FILE_INSTALLER:
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		boxes_unattended_file_set_installer ((BoxesUnattendedFile*) self, g_value_get_object (value));
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		break;
#line 3024 "unattended-file.c"
		default:
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/unattended-file.vala"
		break;
#line 3030 "unattended-file.c"
	}
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if ((array != NULL) && (destroy_func != NULL)) {
#line 3038 "unattended-file.c"
		int i;
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		for (i = 0; i < array_length; i = i + 1) {
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			if (((gpointer*) array)[i] != NULL) {
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				destroy_func (((gpointer*) array)[i]);
#line 3046 "unattended-file.c"
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_vala_array_destroy (array, array_length, destroy_func);
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_free (array);
#line 3058 "unattended-file.c"
}


static gint _vala_array_length (gpointer array) {
	int length;
	length = 0;
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if (array) {
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		while (((gpointer*) array)[length]) {
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			length++;
#line 3071 "unattended-file.c"
		}
	}
#line 473 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	return length;
#line 3076 "unattended-file.c"
}



